大佛普拉斯 (豆瓣)
Description: 大佛普拉斯电影简介和剧情介绍,大佛普拉斯影评、图片、预告片、影讯、论坛、在线购票
Keywords: 大佛普拉斯,大佛普拉斯,大佛普拉斯影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.201豆瓣电影Top250

# 大佛普拉斯 (2017)

导演: 黄信尧
编剧: 黄信尧
主演: 庄益增 / 陈竹昇 / 戴立忍 / 张少怀 / 陈以文 / 纳豆 / 丁国琳 / 李永丰 / 朱约信 / 雷婕熙 / 林美秀 / 小亮哥 / 游安顺 / 梁赫群 / 脱线 / 郑宇彤 / 鲁文学
类型: 剧情 / 喜剧
制片国家/地区: 中国台湾
语言: 闽南语 / 汉语普通话
上映日期: 2017-10-13(中国台湾) / 2017-06-29(台北电影节)
片长: 102分钟
又名: The Great Buddha+
IMDb: tt7010412
豆瓣评分
引用
8.7
424319人评价
5星
48.3%
4星
41.7%
3星
8.8%
2星
0.8%
1星
0.3%
好于 98% 喜剧片
好于 97% 剧情片
想看 看过
评价:
推荐

## 大佛普拉斯的剧情简介 · · · · · ·

菜埔（庄益增 饰）是一家雕塑厂的夜间保安，家中有一位重病的老母亲需要照顾。肚财（陈竹昇 饰）是菜埔唯一的朋友，菜埔经常在值夜班的时候把肚财叫过来和他作伴。一天，两人突发奇想决定看一看菜埔的老板黄启文（戴立忍 饰）的行车记录仪里记录了哪些影像，希望向来风流的老板能够贡献出一些精彩的片段以解两个独身男人内心里的寂寞之苦。
行车记录仪所记录的影像果然没有让菜埔和肚财失望，但与此同时，两人也发现了黄启文的许多不可告人的秘密。实际上，菜埔和肚财的一举一动皆没有逃过黄启文的眼睛，为了保住自己的地位和名声，他决定采取一些必要的行动。 ©豆瓣

## 大佛普拉斯的演职员 · · · · · · ( 全部 27 )

- 黄信尧 导演
- 庄益增 饰 菜埔
- 陈竹昇 饰 肚财
- 戴立忍 饰 黄启文
- 张少怀 饰 释迦
- 陈以文 饰 高委员

## 大佛普拉斯的视频和图片 · · · · · · ( 预告片3 | 视频评论1 · 添加 | 图片1351 · 添加 )

## 大佛普拉斯的获奖情况 · · · · · · ( 全部 )

- 第54届台北金马影展
- 金马奖 最佳剧情片(提名)

- 第37届香港电影金像奖
- 最佳两岸华语电影

- 第42届多伦多国际电影节
- 亚洲电影促进联盟奖
- 黄信尧

## 喜欢这部电影的人也喜欢 · · · · · ·

  同学麦娜丝

  荒蛮故事

  巴斯特·斯克鲁格斯的歌谣

  两杆大烟枪

  疯狂的石头

  驴得水

  让子弹飞

  不成问题的问题

  布达佩斯大饭店

  低俗小说

我要写短评

## 大佛普拉斯的短评 · · · · · · ( 全部 116202 条 )

热门 / 最新 / 好友

### 8353 有用 亚比煞 看过 2018-04-06 09:47:44

你永远不会知道他人的皮囊之下，到底藏着什么样的秘密。就像你不会知道，万人朝拜的菩萨肚子里有一具死尸，也不会知道一个收垃圾的大叔，屋子里摆满了洋娃娃。

### 4463 有用 大島 看过 2018-03-06 21:47:37

那时我们还太年轻,不知道上帝已经在暗地里给每个人都准备好了最后一顿饭。

### 4272 有用 諸笛 看过 2017-10-15 22:25:57

這不完全是黑白片唷。因為有錢人的世界是彩色的。以黑色幽默包裹的社會寫實劇，很貼近台灣社會。導演黃信堯後設的口白，不僅是趣味，也巧妙中和了故事裡那種幾乎沒有出口的黑暗抑鬱。社會階級分化，貧富差距，宗教政經的金玉其外敗絮其中，諷刺的超到位。拍了一個很棒的結局

### 9304 有用 水原吸管 看过 2017-10-14 16:37:46

「雖然現在已經是太空時代了，人類可以搭乘太空船到達月球，但卻沒辦法看穿每個人心裡的宇宙。」

### 6885 有用 王大根 看过 2018-02-16 21:05:09

看到“我要你干我”的时候家里人推门而入，真的百口莫辩

> 更多短评 116202条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 大佛普拉斯的影评 · · · · · · ( 全部 1677 条 )

热门 / 最新 / 好友
大海里的针 2018-02-28 12:33:29 #《大佛普拉斯》中的黑色幽默与社会批判

## 酒肉穿肠过，权欲肚中留

这篇影评可能有剧透

社会常常在讲要公平正义，但在他们的生活之中，应该是没有这四个字，毕竟光是要捧饭碗就没力了，哪还有力气去讲那些有的没的。 2018年春节档内地票房报收56.5亿，对比去年增幅67%，一片繁荣景象。 更重要的是，这个春节档虽然仍有烂片，但是口碑和票房越来越呈正相关了，让人看... (展开)
11436 332 463回应 收起
木卫二 2018-02-15 09:07:37

## 一个人的宇宙

微信公众号：moviesss 首发于 MOViE木卫 “现在已经是太空时代了，人们可以登上月球，却永远无法探索人们内心的宇宙。” 导演黄信尧在片中，说了这么一句旁白。有点像金句，很适合豆瓣电影短评人，或者写上电影日历。 整部电影还没有开始出画面，黄信尧的声音就跳了出来，打... (展开)
2059 241 64回应 收起
李讪然 2018-02-11 15:20:05

## 大佛普拉斯：佛像肚内的众生

这篇影评可能有剧透

第一个要说的就是导演讲故事的方法，《大佛普拉斯》很难被归为某一确定类型的影片。影片一开场导演就跳出来告诉观众，我要给你们讲一个故事，不过在这个故事进行中呢，我还会时不时地跳出来讲两句。接下来，导演还真的担负起了旁白（Voiceover）的责任，而且影片中旁白作用丰富... (展开)
2600 156 206回应 收起
我是尾号2473 2018-03-09 11:11:32

## 有史以来最好玩的一部文艺片

这部片子应该是我看过，有史以来最好玩的一部文艺片 来说说怎么个好玩法吧 首说片名 这部电影的片名之所以叫“大佛普拉斯”，是因为导演黄信尧之前拍过一支短片叫“大佛”，现在片子加长了，干脆像iPhone一样加个plus，所以“大佛普拉斯”的名字就这样来了。 导演还说，“片名... (展开)
967 152 152回应 收起
李露白 2018-03-03 22:16:35 #《大佛普拉斯》是如何刻画小人物的？

## Buddha or Puta？（大佛还是娼妓）

这篇影评可能有剧透

Buddha or Puta？ 这是一部让人看到脊背发凉的电影。小人物令人辛酸的苟且残生，用冷静的幽默表达出来，上层人声色犬马到副议员一幅古惑仔的样子。一笑之后，是抹不去的悲凉。 Buddha在英语里是大佛的意思，Puta在西班牙语里是娼妓的意思。老板黄启文在车里与情人云雨的时候，... (展开)
825 89 72回应 收起
胡乐乎 2018-03-05 18:14:31

## 肚财是被启文杀的吗

这篇影评可能有剧透

电影中，肚财的死被警察判定为：过量饮酒，然后被撞死了。 大家都知道，肚财从不喝酒，而且一般都是喝酒的撞死人，哪有喝酒的被撞死的，最重要的是，肚财还是一个买不起酒，一天只吃得起一顿饭的穷光蛋。 作为观影人，有着上帝视角的观影人，大家的直觉，几乎认定了是启文杀死... (展开)
791 33 114回应 收起
东方翠瓜 2018-05-05 02:14:16 #《大佛普拉斯》中的旁白表现手法怎么样？

## 电影中的那些旁白

这篇影评可能有剧透

觉得电影的旁白真的很幽默，笑过之后又真的让人心酸，就又看了一遍做了些整理。 1.这个工厂大家都很关心对方的老母，那是一种人与人之间的关怀，菜埔白天的工作都是兼差的，正式的工作是在这里当夜班警卫，他会顺便在大家下班前把工厂打扫一下。 2.在外面大小声的，是工厂的老... (展开)
423 5 37回应 收起
Sigma von Zeta 2018-01-21 19:52:23

## 导演qna速记

这篇影评可能有剧透

记得多少就写多少。 表白导演。又可爱又接地气，台语很好听，口白我听不太懂但现场回答我都听懂了(x 1，影片色彩。 黑白是因为铜制大佛很贵，在短片拍摄时有经费上的考虑，用黑白拍摄并且加深对比就能较大程度上解决材质的问题。行车记录仪的内容是彩色的也是沿用短片的想法和... (展开)
178 26 14回应 收起
李霁琛 2018-02-22 00:00:55

## 如果可以发明一种新的电影类型名称，我会将它归类为：操蛋片

这篇影评可能有剧透

一 某些影评人喜欢说“港片已死”，更喜欢说“台片必死”。 但《大佛普拉斯》的存在，似乎是在宣告： 台湾电影生机勃勃。 不但生机勃勃，还制造了2017年华语电影的最大惊喜。 “惊喜”比“喜”多了一个“惊”字。 多出的是意外。 《大佛普拉斯》有太多让人意想不到的妙... (展开)
379 52 34回应 收起
路米內 2018-02-21 00:19:11 #《大佛普拉斯》中的黑色幽默与社会批判

## 大佛肚中的赤裸生命

在看过《大佛普拉斯》后，不少人都把它和2016年钟孟宏的影片《一路顺风》作起比较。把《大佛普拉斯》和《一路顺风》放在一起，不仅仅是因为两者从摄影（钟孟宏化名的中岛长雄），剪辑（赖秀雄），美术指导（赵思豪），到演员（纳豆、庄益增、陈以文、林美秀、还有戴立忍），甚... (展开)
303 43 27回应 收起

> 更多影评 1677篇

添加新讨论

## 讨论区 · · · · · ·

请教哪儿可以看呢~ | 来自苌从 | 6 回应 | 2022-11-22 20:09:09
内心的宇宙 | 来自捷捷捷捷报频传 |  | 2022-11-21 22:29:00
在哪里可以哦看啊 | 来自盼盼 | 27 回应 | 2022-11-21 04:36:30
底层人真的无能为力吗？ | 来自水美竹天 | 5 回应 | 2022-11-16 09:24:36
为什么要藏到佛像里面 | 来自Edward | 6 回应 | 2022-11-15 23:06:08

> 去这部影片的讨论区（全部490条）

## 关于《大佛普拉斯》的问题 · · · · · · ( 全部27个 )

- 肚财的真正死因是什么？ 22人回答
- 自杀男人那段的意思是？ 11人回答

> 全部27个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 上瘾黑色幽默 (闪正)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 亚洲的好电影 (一一)

## 谁在看这部电影 · · · · · ·

- 南望
  刚刚 看过
- 再见白丝
  3分钟前 想看
- PASSER-BY
  4分钟前 想看

546606人看过 / 342866人想看

订阅大佛普拉斯的评论:
feed: rss 2.0